# This is because we want to draw splash screen before time-consuming imports
from lisa.main import lisa_main
# from .main import lisa_main
# import main
lisa_main()
